@@ -18,9 +18,11 @@ import os
 import sys
 
 from . import info
+
 pjoin = os.path.join
 
-root = os.path.abspath(pjoin(os.path.dirname(__file__), os.path.pardir))
+buildutils = os.path.abspath(os.path.dirname(__file__))
+root = pjoin(buildutils, os.path.pardir)
 
 sys.path.insert(0, pjoin(root, 'zmq', 'utils'))
 from constant_names import all_names, no_prefix
@@ -30,6 +32,7 @@ ifndef_t = """#ifndef {0}
 #endif
 """
 
+
 def cython_enums():
     """generate `enum: ZMQ_CONST` block for constant_enums.pxi"""
     lines = []
@@ -38,9 +41,10 @@ def cython_enums():
             lines.append('enum: ZMQ_{0} "{0}"'.format(name))
         else:
             lines.append('enum: ZMQ_{0}'.format(name))
-            
+
     return dict(ZMQ_ENUMS='\n    '.join(lines))
 
+
 def ifndefs():
     """generate `#ifndef ZMQ_CONST` block for zmq_constants.h"""
     lines = ['#define _PYZMQ_UNDEFINED (-9999)']
@@ -50,6 +54,16 @@ def ifndefs():
         lines.append(ifndef_t.format(name))
     return dict(ZMQ_IFNDEFS='\n'.join(lines))
 
+
+def constants_pyi():
+    """Generate CONST: int for mypy"""
+    lines = []
+    for name in all_names:
+        lines.append(f"{name}: int")
+
+    return dict(constants="\n".join(lines))
+
+
 def constants_pyx():
     """generate CONST = ZMQ_CONST and __all__ for constants.pxi"""
     all_lines = []
@@ -63,6 +77,7 @@ def constants_pyx():
         all_lines.append('  "{0}",'.format(name))
     return dict(ASSIGNMENTS='\n'.join(assign_lines), ALL='\n'.join(all_lines))
 
+
 def generate_file(fname, ns_func, dest_dir="."):
     """generate a constants file from its template"""
     with open(pjoin(root, 'buildutils', 'templates', '%s' % fname), 'r') as f:
@@ -73,11 +88,19 @@ def generate_file(fname, ns_func, dest_dir="."):
     with open(dest, 'w') as f:
         f.write(out)
 
+
 def render_constants():
     """render generated constant files from templates"""
-    generate_file("constant_enums.pxi", cython_enums, pjoin(root, 'zmq', 'backend', 'cython'))
-    generate_file("constants.pxi", constants_pyx, pjoin(root, 'zmq', 'backend', 'cython'))
+    generate_file(
+        "constant_enums.pxi", cython_enums, pjoin(root, 'zmq', 'backend', 'cython')
+    )
+    generate_file(
+        "constants.pxi", constants_pyx, pjoin(root, 'zmq', 'backend', 'cython')
+    )
+    generate_file("constants.pyi", constants_pyi, pjoin(root, 'zmq', 'sugar'))
+    generate_file("constants.pyi", constants_pyi, pjoin(root, 'zmq', 'backend'))
     generate_file("zmq_constants.h", ifndefs, pjoin(root, 'zmq', 'utils'))
 
+
 if __name__ == '__main__':
     render_constants()
