@@ -10,12 +10,12 @@ sys.path.append(os.path.abspath('sphinxext'))
 # import sphinx_cython
 from apigen import ApiDocWriter
 
-#*****************************************************************************
+# *****************************************************************************
 if __name__ == '__main__':
     pjoin = os.path.join
     package = 'zmq'
-    outdir = pjoin('source','api','generated')
-    docwriter = ApiDocWriter(package,rst_extension='.rst')
+    outdir = pjoin('source', 'api', 'generated')
+    docwriter = ApiDocWriter(package, rst_extension='.rst')
     # You have to escape the . here because . is a special char for regexps.
     # You must do make clean if you change this!
     docwriter.package_skip_patterns += [
@@ -39,12 +39,10 @@ if __name__ == '__main__':
         r'\.utils\.rebuffer$',
         r'\.utils\.strtypes$',
         r'\.zmq$',
-        ]
-    
+    ]
+
     # Now, generate the outputs
     docwriter.write_api_docs(outdir)
-    docwriter.write_index(outdir, 'gen',
-                          relative_to = pjoin('source','api')
-                          )
-    
+    docwriter.write_index(outdir, 'gen', relative_to=pjoin('source', 'api'))
+
     print('%d files written' % len(docwriter.written_modules))
