@@ -1,16 +1,16 @@
 """A thorough test of polling PUB/SUB sockets."""
 
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 #  Copyright (c) 2010 Brian Granger
 #
 #  Distributed under the terms of the New BSD License.  The full license is in
 #  the file COPYING.BSD, distributed as part of this software.
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 
 import time
 import zmq
 
-print "Running polling tets for PUB/SUB sockets..."
+print("Running polling tets for PUB/SUB sockets...")
 
 addr = 'tcp://127.0.0.1:5555'
 ctx = zmq.Context()
@@ -25,13 +25,13 @@ s2.connect(addr)
 time.sleep(1.0)
 
 poller = zmq.Poller()
-poller.register(s1, zmq.POLLIN|zmq.POLLOUT)
-poller.register(s2, zmq.POLLIN|zmq.POLLOUT)
+poller.register(s1, zmq.POLLIN | zmq.POLLOUT)
+poller.register(s2, zmq.POLLIN | zmq.POLLOUT)
 
 # Now make sure that both are send ready.
 socks = dict(poller.poll())
 assert socks[s1] == zmq.POLLOUT
-assert not socks.has_key(s2)
+assert s2 not in socks
 
 # Make sure that s1 stays in POLLOUT after a send.
 s1.send('msg1')
@@ -46,7 +46,7 @@ assert socks[s2] == zmq.POLLIN
 # Make sure that s2 goes into 0 after recv.
 s2.recv()
 socks = dict(poller.poll())
-assert not socks.has_key(s2)
+assert s2 not in socks
 
 poller.unregister(s1)
 poller.unregister(s2)
@@ -54,4 +54,4 @@ poller.unregister(s2)
 # Wait for everything to finish.
 time.sleep(1.0)
 
-print "Finished."
+print("Finished.")
