@@ -3,16 +3,18 @@
 # Copyright (c) PyZMQ Developers.
 # Distributed under the terms of the Modified BSD License.
 
+import warnings
 from collections import namedtuple, deque
 from itertools import chain
+from typing import Type
 
 from zmq import EVENTS, POLLOUT, POLLIN
 import zmq as _zmq
 
-_FutureEvent = namedtuple('_FutureEvent', ('future', 'kind', 'kwargs', 'msg'))
+_FutureEvent = namedtuple('_FutureEvent', ('future', 'kind', 'kwargs', 'msg', 'timer'))
 
 # These are incomplete classes and need a Mixin for compatibility with an eventloop
-# defining the followig attributes:
+# defining the following attributes:
 #
 # _Future
 # _READ
@@ -20,9 +22,40 @@ _FutureEvent = namedtuple('_FutureEvent', ('future', 'kind', 'kwargs', 'msg'))
 # _default_loop()
 
 
-class _AsyncPoller(_zmq.Poller):
+class _Async:
+    """Mixin for common async logic"""
+
+    _current_loop = None
+
+    def _get_loop(self):
+        """Get event loop
+
+        Notice if event loop has changed,
+        and register init_io_state on activation of a new event loop
+        """
+        if self._current_loop is None:
+            self._current_loop = self._default_loop()
+            self._init_io_state(self._current_loop)
+            return self._current_loop
+        current_loop = self._default_loop()
+        if current_loop is not self._current_loop:
+            # warn? This means a socket is being used in multiple loops!
+            self._current_loop = current_loop
+            self._init_io_state(current_loop)
+        return current_loop
+
+    def _default_loop(self):
+        raise NotImplementedError("Must be implemented in a subclass")
+
+    def _init_io_state(self, loop=None):
+        pass
+
+
+class _AsyncPoller(_Async, _zmq.Poller):
     """Poller that returns a Future on poll, instead of blocking."""
 
+    _socket_class = None  # type: Type[_AsyncSocket]
+
     def poll(self, timeout=-1):
         """Return a Future for a poll event"""
         future = self._Future()
@@ -34,19 +67,22 @@ class _AsyncPoller(_zmq.Poller):
             else:
                 future.set_result(result)
             return future
-        
-        loop = self._default_loop()
-        
+
+        loop = self._get_loop()
+
         # register Future to be called as soon as any event is available on any socket
         watcher = self._Future()
-        
+
         # watch raw sockets:
         raw_sockets = []
+
         def wake_raw(*args):
             if not watcher.done():
                 watcher.set_result(None)
 
-        watcher.add_done_callback(lambda f: self._unwatch_raw_sockets(loop, *raw_sockets))
+        watcher.add_done_callback(
+            lambda f: self._unwatch_raw_sockets(loop, *raw_sockets)
+        )
 
         for socket, mask in self.sockets:
             if isinstance(socket, _zmq.Socket):
@@ -85,41 +121,49 @@ class _AsyncPoller(_zmq.Poller):
                     future.set_exception(e)
                 else:
                     future.set_result(result)
+
         watcher.add_done_callback(on_poll_ready)
-        
+
         if timeout is not None and timeout > 0:
             # schedule cancel to fire on poll timeout, if any
             def trigger_timeout():
                 if not watcher.done():
                     watcher.set_result(None)
-            
-            timeout_handle = loop.call_later(
-                1e-3 * timeout,
-                trigger_timeout
-            )
+
+            timeout_handle = loop.call_later(1e-3 * timeout, trigger_timeout)
+
             def cancel_timeout(f):
                 if hasattr(timeout_handle, 'cancel'):
                     timeout_handle.cancel()
                 else:
                     loop.remove_timeout(timeout_handle)
+
             future.add_done_callback(cancel_timeout)
 
         def cancel_watcher(f):
             if not watcher.done():
                 watcher.cancel()
+
         future.add_done_callback(cancel_watcher)
 
         return future
 
 
-class _AsyncSocket(_zmq.Socket):
+class _NoTimer:
+    @staticmethod
+    def cancel():
+        pass
 
+
+class _AsyncSocket(_Async, _zmq.Socket):
+
+    # Warning : these class variables are only here to allow to call super().__setattr__.
+    # They be overridden at instance initialization and not shared in the whole class
     _recv_futures = None
     _send_futures = None
     _state = 0
     _shadow_sock = None
     _poller_class = _AsyncPoller
-    io_loop = None
     _fd = None
 
     def __init__(self, context=None, socket_type=-1, io_loop=None, **kwargs):
@@ -133,12 +177,18 @@ class _AsyncSocket(_zmq.Socket):
         else:
             super(_AsyncSocket, self).__init__(context, socket_type, **kwargs)
             self._shadow_sock = _zmq.Socket.shadow(self.underlying)
-        self.io_loop = io_loop or self._default_loop()
+
+        if io_loop is not None:
+            warnings.warn(
+                f"{self.__class__.__name__}(io_loop) argument is deprecated in pyzmq 22.2."
+                " The currently active loop will always be used.",
+                DeprecationWarning,
+                stacklevel=3,
+            )
         self._recv_futures = deque()
         self._send_futures = deque()
         self._state = 0
         self._fd = self._shadow_sock.FD
-        self._init_io_state()
 
     @classmethod
     def from_socket(cls, socket, io_loop=None):
@@ -146,8 +196,10 @@ class _AsyncSocket(_zmq.Socket):
         return cls(_from_socket=socket, io_loop=io_loop)
 
     def close(self, linger=None):
-        if not self.closed:
-            for event in list(chain(self._recv_futures, self._send_futures)):
+        if not self.closed and self._fd is not None:
+            for event in list(
+                chain(self._recv_futures or [], self._send_futures or [])
+            ):
                 if not event.future.done():
                     try:
                         event.future.cancel()
@@ -156,6 +208,7 @@ class _AsyncSocket(_zmq.Socket):
                         pass
             self._clear_io_state()
         super(_AsyncSocket, self).close(linger=linger)
+
     close.__doc__ = _zmq.Socket.close.__doc__
 
     def get(self, key):
@@ -163,17 +216,18 @@ class _AsyncSocket(_zmq.Socket):
         if key == EVENTS:
             self._schedule_remaining_events(result)
         return result
+
     get.__doc__ = _zmq.Socket.get.__doc__
 
     def recv_multipart(self, flags=0, copy=True, track=False):
         """Receive a complete multipart zmq message.
-        
+
         Returns a Future whose result will be a multipart message.
         """
-        return self._add_recv_event('recv_multipart',
-            dict(flags=flags, copy=copy, track=track)
+        return self._add_recv_event(
+            'recv_multipart', dict(flags=flags, copy=copy, track=track)
         )
-    
+
     def recv(self, flags=0, copy=True, track=False):
         """Receive a single zmq frame.
 
@@ -181,9 +235,7 @@ class _AsyncSocket(_zmq.Socket):
 
         Recommend using recv_multipart instead.
         """
-        return self._add_recv_event('recv',
-            dict(flags=flags, copy=copy, track=track)
-        )
+        return self._add_recv_event('recv', dict(flags=flags, copy=copy, track=track))
 
     def send_multipart(self, msg, flags=0, copy=True, track=False, **kwargs):
         """Send a complete multipart zmq message.
@@ -211,6 +263,7 @@ class _AsyncSocket(_zmq.Socket):
     def _deserialize(self, recvd, load):
         """Deserialize with Futures"""
         f = self._Future()
+
         def _chain(_):
             """Chain result through serialization to recvd"""
             if f.done():
@@ -225,6 +278,7 @@ class _AsyncSocket(_zmq.Socket):
                     f.set_exception(e)
                 else:
                     f.set_result(loaded)
+
         recvd.add_done_callback(_chain)
 
         def _chain_cancel(_):
@@ -233,6 +287,7 @@ class _AsyncSocket(_zmq.Socket):
                 return
             if f.cancelled():
                 recvd.cancel()
+
         f.add_done_callback(_chain_cancel)
 
         return f
@@ -251,6 +306,7 @@ class _AsyncSocket(_zmq.Socket):
         f = p.poll(timeout)
 
         future = self._Future()
+
         def unwrap_result(f):
             if future.done():
                 return
@@ -276,6 +332,7 @@ class _AsyncSocket(_zmq.Socket):
 
     def _add_timeout(self, future, timeout):
         """Add a timeout for a send or recv Future"""
+
         def future_timeout():
             if future.done():
                 # future already resolved, do nothing
@@ -283,7 +340,8 @@ class _AsyncSocket(_zmq.Socket):
 
             # raise EAGAIN
             future.set_exception(_zmq.Again())
-        self._call_later(timeout, future_timeout)
+
+        return self._call_later(timeout, future_timeout)
 
     def _call_later(self, delay, callback):
         """Schedule a function to be called later
@@ -293,7 +351,7 @@ class _AsyncSocket(_zmq.Socket):
         Tornado and asyncio happen to both have ioloop.call_later
         with the same signature.
         """
-        self.io_loop.call_later(delay, callback)
+        return self._get_loop().call_later(delay, callback)
 
     @staticmethod
     def _remove_finished_future(future, event_list):
@@ -302,14 +360,13 @@ class _AsyncSocket(_zmq.Socket):
         Avoids delaying cleanup until the next send/recv event,
         which may never come.
         """
-        if getattr(future, '_pyzmq_popped', False):
-            return
-        for f_idx, (f, kind, kwargs, _) in enumerate(event_list):
-            if f is future:
+        for f_idx, event in enumerate(event_list):
+            if event.future is future:
                 break
         else:
             return
-        future._pyzmq_popped = True
+
+        # "future" instance is shared between sockets, but each socket has its own event list.
         event_list.remove(event_list[f_idx])
 
     def _add_recv_event(self, kind, kwargs=None, future=None):
@@ -326,19 +383,20 @@ class _AsyncSocket(_zmq.Socket):
                 f.set_result(r)
             return f
 
-        # we add it to the list of futures before we add the timeout as the
-        # timeout will remove the future from recv_futures to avoid leaks
-        self._recv_futures.append(
-            _FutureEvent(f, kind, kwargs, msg=None)
-        )
-
-        # Don't let the Future sit in _recv_events after it's done
-        f.add_done_callback(lambda f: self._remove_finished_future(f, self._recv_futures))
-
+        timer = _NoTimer
         if hasattr(_zmq, 'RCVTIMEO'):
             timeout_ms = self._shadow_sock.rcvtimeo
             if timeout_ms >= 0:
-                self._add_timeout(f, timeout_ms * 1e-3)
+                timer = self._add_timeout(f, timeout_ms * 1e-3)
+
+        # we add it to the list of futures before we add the timeout as the
+        # timeout will remove the future from recv_futures to avoid leaks
+        self._recv_futures.append(_FutureEvent(f, kind, kwargs, msg=None, timer=timer))
+
+        # Don't let the Future sit in _recv_events after it's done
+        f.add_done_callback(
+            lambda f: self._remove_finished_future(f, self._recv_futures)
+        )
 
         if self._shadow_sock.get(EVENTS) & POLLIN:
             # recv immediately, if we can
@@ -353,10 +411,7 @@ class _AsyncSocket(_zmq.Socket):
         # attempt send with DONTWAIT if no futures are waiting
         # short-circuit for sends that will resolve immediately
         # only call if no send Futures are waiting
-        if (
-            kind in ('send', 'send_multipart')
-            and not self._send_futures
-        ):
+        if kind in ('send', 'send_multipart') and not self._send_futures:
             flags = kwargs.get('flags', 0)
             nowait_kwargs = kwargs.copy()
             nowait_kwargs['flags'] = flags | _zmq.DONTWAIT
@@ -387,18 +442,21 @@ class _AsyncSocket(_zmq.Socket):
                     self._schedule_remaining_events()
                 return f
 
-        # we add it to the list of futures before we add the timeout as the
-        # timeout will remove the future from recv_futures to avoid leaks
-        self._send_futures.append(
-            _FutureEvent(f, kind, kwargs=kwargs, msg=msg)
-        )
-        # Don't let the Future sit in _send_futures after it's done
-        f.add_done_callback(lambda f: self._remove_finished_future(f, self._send_futures))
-
+        timer = _NoTimer
         if hasattr(_zmq, 'SNDTIMEO'):
             timeout_ms = self._shadow_sock.get(_zmq.SNDTIMEO)
             if timeout_ms >= 0:
-                self._add_timeout(f, timeout_ms * 1e-3)
+                timer = self._add_timeout(f, timeout_ms * 1e-3)
+
+        # we add it to the list of futures before we add the timeout as the
+        # timeout will remove the future from recv_futures to avoid leaks
+        self._send_futures.append(
+            _FutureEvent(f, kind, kwargs=kwargs, msg=msg, timer=timer)
+        )
+        # Don't let the Future sit in _send_futures after it's done
+        f.add_done_callback(
+            lambda f: self._remove_finished_future(f, self._send_futures)
+        )
 
         self._add_io_state(POLLOUT)
         return f
@@ -410,8 +468,7 @@ class _AsyncSocket(_zmq.Socket):
             return
         f = None
         while self._recv_futures:
-            f, kind, kwargs, _ = self._recv_futures.popleft()
-            f._pyzmq_popped = True
+            f, kind, kwargs, _, timer = self._recv_futures.popleft()
             # skip any cancelled futures
             if f.done():
                 f = None
@@ -424,6 +481,8 @@ class _AsyncSocket(_zmq.Socket):
         if f is None:
             return
 
+        timer.cancel()
+
         if kind == 'poll':
             # on poll event, just signal ready, nothing else.
             f.set_result(None)
@@ -434,7 +493,7 @@ class _AsyncSocket(_zmq.Socket):
             recv = self._shadow_sock.recv
         else:
             raise ValueError("Unhandled recv event type: %r" % kind)
-        
+
         kwargs['flags'] |= _zmq.DONTWAIT
         try:
             result = recv(**kwargs)
@@ -442,27 +501,28 @@ class _AsyncSocket(_zmq.Socket):
             f.set_exception(e)
         else:
             f.set_result(result)
-    
+
     def _handle_send(self):
         if not self._shadow_sock.get(EVENTS) & POLLOUT:
             # event triggered, but state may have been changed between trigger and callback
             return
         f = None
         while self._send_futures:
-            f, kind, kwargs, msg = self._send_futures.popleft()
-            f._pyzmq_popped = True
+            f, kind, kwargs, msg, timer = self._send_futures.popleft()
             # skip any cancelled futures
             if f.done():
                 f = None
             else:
                 break
-        
+
         if not self._send_futures:
             self._drop_io_state(POLLOUT)
 
         if f is None:
             return
-        
+
+        timer.cancel()
+
         if kind == 'poll':
             # on poll event, just signal ready, nothing else.
             f.set_result(None)
@@ -473,7 +533,7 @@ class _AsyncSocket(_zmq.Socket):
             send = self._shadow_sock.send
         else:
             raise ValueError("Unhandled send event type: %r" % kind)
-        
+
         kwargs['flags'] |= _zmq.DONTWAIT
         try:
             result = send(msg, **kwargs)
@@ -481,7 +541,7 @@ class _AsyncSocket(_zmq.Socket):
             f.set_exception(e)
         else:
             f.set_result(result)
-    
+
     # event masking from ZMQStream
     def _handle_events(self, fd=0, events=0):
         """Dispatch IO events to _handle_recv, etc."""
@@ -525,11 +585,17 @@ class _AsyncSocket(_zmq.Socket):
 
         zmq FD is always read-only.
         """
+        # ensure loop is registered and init_io has been called
+        # if there are any events to watch for
+        if state:
+            self._get_loop()
         self._schedule_remaining_events()
 
-    def _init_io_state(self):
+    def _init_io_state(self, loop=None):
         """initialize the ioloop event handler"""
-        self.io_loop.add_handler(self._shadow_sock, self._handle_events, self._READ)
+        if loop is None:
+            loop = self._get_loop()
+        loop.add_handler(self._shadow_sock, self._handle_events, self._READ)
         self._call_later(0, self._handle_events)
 
     def _clear_io_state(self):
@@ -540,6 +606,5 @@ class _AsyncSocket(_zmq.Socket):
         fd = self._shadow_sock
         if self._shadow_sock.closed:
             fd = self._fd
-        self.io_loop.remove_handler(fd)
-
-
+        if self._current_loop is not None:
+            self._current_loop.remove_handler(fd)
